@@ -14,19 +14,19 @@ TESTFILES = [
     'base.rst',
     'utils.rst',
     'locking.rst',
-    'parts/alias.rst',
-    'parts/attributes.rst',
-    'parts/cache.rst',
-    'parts/lifecycle.rst',
-    'parts/mapping.rst',
-    'parts/nodespace.rst',
-    'parts/nodify.rst',
-    'parts/order.rst',
-    'parts/reference.rst',
-    'parts/storage.rst',
+    'behaviors/alias.rst',
+    'behaviors/attributes.rst',
+    'behaviors/cache.rst',
+    'behaviors/lifecycle.rst',
+    'behaviors/mapping.rst',
+    'behaviors/nodespace.rst',
+    'behaviors/nodify.rst',
+    'behaviors/order.rst',
+    'behaviors/reference.rst',
+    'behaviors/storage.rst',
     '../../README.rst',
     # at very end, ``GetattrChildren`` tests break coverage recording
-    'parts/common.rst',
+    'behaviors/common.rst',
 ]
 
 def test_suite():
